@@ -212,7 +212,7 @@ class Extract:
                              xytext=(0,10),
                              ha='center',
                              fontsize=fontsize,
-                             rotation=rotation,
+                             rotation=0.,
                              color=color
                             )
         tmpmask = mask.astype(float)
